@@ -1,14 +1,17 @@
 package Acme::PERLANCAR::Dummy::ModuleFeatures::Module1::_ModuleFeatures;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-25'; # DATE
+our $DATE = '2021-02-26'; # DATE
 our $DIST = 'Acme-PERLANCAR-Dummy'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use strict;
 use warnings;
 
 our %FEATURES = (
+    set_v => {
+        Dummy => 2,
+    },
     features => {
         Dummy => {
             feature1 => 0,
@@ -33,7 +36,7 @@ Acme::PERLANCAR::Dummy::ModuleFeatures::Module1::_ModuleFeatures - A feature dec
 
 =head1 VERSION
 
-This document describes version 0.005 of Acme::PERLANCAR::Dummy::ModuleFeatures::Module1::_ModuleFeatures (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-02-25.
+This document describes version 0.006 of Acme::PERLANCAR::Dummy::ModuleFeatures::Module1::_ModuleFeatures (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-02-26.
 
 =head1 DESCRIPTION
 
